package org.apache.ddlutils.model;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */


import static java.util.Arrays.asList;

/**
 * Represents the different cascade actions for the <code>onDelete</code> and
 * <code>onUpdate</code> properties of {@link ForeignKey}.
 * 
 * @version $Revision: $
 */
public enum  CascadeActionEnum
{
    CASCADE("cascade"), SET_NULL("setnull"), SET_DEFAULT("setdefault"), RESTRICT("restrict"), NONE("none");

    private final String enumName;

    CascadeActionEnum(String enumName) {
        this.enumName = enumName;
    }

    public String getName(){
        return enumName;
    }

    public static CascadeActionEnum fromString(String value) {
        for (CascadeActionEnum cascadeActionEnum : values()) {
            if(cascadeActionEnum.enumName.equals(value)){
                return cascadeActionEnum;
            }
        }
        throw new IllegalArgumentException(value + " does not match any of " + asList(values()));
    }
}
